@@ -31,7 +31,7 @@ Isotope::~Isotope()
 {
 }
 
-void Isotope::addData(ChemicalDataObject o)
+void Isotope::addData(const ChemicalDataObject &o)
 {
     if (o.type() == ChemicalDataObject::exactMass) {
         m_mass = o;
@@ -94,7 +94,6 @@ QString Isotope::magmoment() const
 QString Isotope::abundance() const
 {
     return m_abundance.value().toString();
-    return QString();
 }
 
 double Isotope::halflife() const
